import 'package:fholdergrid/fholdergrid.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';

void main() {
  runApp(App());
}

class App extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: HomeScreen(),
    );
  }
}

class HomeScreen extends StatefulWidget {
  HomeScreen();

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  final ImagePicker _imagePicker = ImagePicker();
  final int _maxNumberOfImages = 4;
  final List<String> _paths = List.filled(4, '');

  int _lastInsertedIndex = 0;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        title: Text('fholdergrid'),
      ),
      body: SafeArea(
        minimum: const EdgeInsets.all(16.0),
        child: FHolderGrid(
          maxNumberOfItems: _maxNumberOfImages,
          cache: _paths,
        ),
      ),
      floatingActionButton: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.end,
        children: [
          FloatingActionButton.extended(
            label: Text('From storage'),
            icon: Icon(Icons.storage),
            onPressed: () async {
              await _getImage(fromCamera: false);
            },
          ),
          SizedBox(
            height: 16.0,
          ),
          FloatingActionButton.extended(
            label: Text('From camera'),
            icon: Icon(Icons.camera),
            onPressed: () async {
              await _getImage(fromCamera: true);
            },
          ),
        ],
      ),
    );
  }

  Future<void> _getImage({@required bool fromCamera}) async {
    final image = await _imagePicker.getImage(
      source: fromCamera ? ImageSource.camera : ImageSource.gallery,
    );

    setState(() {
      if (_lastInsertedIndex < _maxNumberOfImages) {
        _paths[_lastInsertedIndex] = image.path;
        _lastInsertedIndex++;
      }
    });
  }
}
