/// Widget for loading images from storage or camera into grid placeholders. This
/// is a lightweight library which only uses native packages
library fholdergrid;

import 'dart:io';
import 'package:flutter/material.dart';

/// Main widget class which extends Material's [StatelessWidget] and accepts two
/// parameters: [maxNumberOfItems] and [cache]
class FHolderGrid extends StatelessWidget {
  /// Max number of items that the [GridView can display]
  final int maxNumberOfItems;

  /// String list of image paths, either from the storage or camera pics
  final List<String> cache;

  /// Constructor which creates the [FHolderGrid] widget with two required
  /// parameters: [maxNumberOfItems] and [cache]
  FHolderGrid({@required this.maxNumberOfItems, @required this.cache});

  /// Overriden build method
  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: 2,
        mainAxisSpacing: 4.0,
        crossAxisSpacing: 4.0,
      ),
      itemCount: maxNumberOfItems,
      itemBuilder: (BuildContext cntx, int index) =>
          cache != null && cache[index].isNotEmpty
              ? Image.file(File(cache[index]), fit: BoxFit.fitWidth)
              : Container(color: Colors.grey[300]),
    );
  }
}
